@@ -207,8 +207,12 @@ PositionStackAndNudge <-
 
                    setup_params = function(self, data) {
                      c(
-                       list(nudge_x = self$x, nudge_y = self$y,
-                            .fun_x = self$.fun_x, .fun_y = self$.fun_y,
+                       list(nudge_x = self$x,
+                            nudge_y = self$y,
+                            .fun_x = self$.fun_x,
+                            .fun_y = self$.fun_y,
+                            x.reorder = !is.null(self$x) && length(self$x) > 1 && length(self$x) < nrow(data),
+                            y.reorder = !is.null(self$y) && length(self$y) > 1 && length(self$y) < nrow(data),
                             kept.origin = self$kept.origin),
                        ggplot2::ggproto_parent(ggplot2::PositionStack, self)$setup_params(data)
                      )
@@ -234,13 +238,31 @@ PositionStackAndNudge <-
                    },
 
                    compute_layer = function(self, data, params, layout) {
+                     if (length(params$nudge_x) > nrow(data)) {
+                       warning("Argument 'x' longer than data: some values dropped!")
+                     }
+                     if (length(params$nudge_y) > nrow(data)) {
+                       warning("Argument 'y' longer than data: some values dropped!")
+                     }
                      x_orig <- data$x
+                     y_orig <- data$y
 
                      # operate on the stacked positions (updated in August 2020)
                      data = ggplot2::ggproto_parent(ggplot2::PositionStack, self)$compute_layer(data, params, layout)
                      x_stacked <- data$x
                      y_stacked <- data$y
 
+                     if (params$x.reorder) {
+                       params$nudge_x <- rep_len(params$nudge_x, nrow(data))[order(order(data$x))]
+                     } else {
+                       params$nudge_x <- rep_len(params$nudge_x, nrow(data))
+                     }
+                     if (params$y.reorder) {
+                       params$nudge_y <- rep_len(params$nudge_y, nrow(data))[order(order(data$y))]
+                     } else {
+                       params$nudge_y <- rep_len(params$nudge_y, nrow(data))
+                     }
+
                      # transform only the dimensions for which non-zero nudging is requested
                      if (any(params$nudge_x != 0)) {
                        if (any(params$nudge_y != 0)) {
@@ -280,13 +302,14 @@ PositionStackAndNudge <-
 #'
 position_stack_keep <-
   function(vjust = 1,
-           reverse = FALSE) {
+           reverse = FALSE,
+           kept.origin = "original") {
     position_stacknudge(vjust = vjust,
                         reverse = reverse,
                         x = 0,
                         y = 0,
                         direction = "none",
-                        kept.origin = "original")
+                        kept.origin = kept.origin)
   }
 
 #' @rdname ggpp-ggproto
@@ -304,13 +327,14 @@ PositionFillAndNudge <-
 #'
 position_fill_keep <-
   function(vjust = 1,
-           reverse = FALSE) {
+           reverse = FALSE,
+           kept.origin = "original") {
     position_fillnudge(vjust = vjust,
                        reverse = reverse,
                        x = 0,
                        y = 0,
                        direction = "none",
-                       kept.origin = "original")
+                       kept.origin = kept.origin)
   }
 
 #' @rdname ggpp-ggproto
@@ -325,15 +349,20 @@ PositionStackMinMax <-
 
                    setup_params = function(self, data) {
                      c(
-                       list(nudge_x = self$x, nudge_y = self$y,
-                            .fun_x = self$.fun_x, .fun_y = self$.fun_y,
+                       list(nudge_x = self$x,
+                            nudge_y = self$y,
+                            .fun_x = self$.fun_x,
+                            .fun_y = self$.fun_y,
+                            x.reorder = !is.null(self$x) && length(self$x) > 1 && length(self$x) < nrow(data),
+                            y.reorder = !is.null(self$y) && length(self$y) > 1 && length(self$y) < nrow(data),
                             kept.origin = self$kept.origin,
-                            var = self$var, fill = FALSE),
+                            var = self$var,
+                            fill = FALSE),
                        ggplot2::ggproto_parent(ggplot2::PositionStack, self)$setup_params(data)
                      )
                    },
 
-                                      setup_data = function(self, data, params) {
+                   setup_data = function(self, data, params) {
                      data <- flip_data(data, params$flipped_aes)
                      if (!(exists("ymax", data) && exists("ymin", data) && exists("y", data))) {
                        stop("position_stack_minmax() requires y, ymin and ymax mappings in data")
@@ -342,6 +371,13 @@ PositionStackMinMax <-
                    },
 
                    compute_layer = function(self, data, params, layout) {
+
+                     if (length(params$nudge_x) > nrow(data)) {
+                       warning("Argument 'x' longer than data: some values dropped!")
+                     }
+                     if (length(params$nudge_y) > nrow(data)) {
+                       warning("Argument 'y' longer than data: some values dropped!")
+                     }
                      x_orig <- data$x
                      if (exists("xmin", data)) {
                        xmin_delta <-  data$xmin - data$x
@@ -375,6 +411,17 @@ PositionStackMinMax <-
                      if (exists("ymin", data)) data$ymin <- data$y + ymin_delta
                      if (exists("ymax", data)) data$ymax <- data$y + ymax_delta
 
+                     if (params$x.reorder) {
+                       params$nudge_x <- rep_len(params$nudge_x, nrow(data))[order(order(data$x))]
+                     } else {
+                       params$nudge_x <- rep_len(params$nudge_x, nrow(data))
+                     }
+                     if (params$y.reorder) {
+                       params$nudge_y <- rep_len(params$nudge_y, nrow(data))[order(order(data$y))]
+                     } else {
+                       params$nudge_y <- rep_len(params$nudge_y, nrow(data))
+                     }
+
                      # transform only the dimensions for which non-zero nudging is requested
                      if (any(params$nudge_x != 0)) {
                        if (any(params$nudge_y != 0)) {
