@@ -14,11 +14,11 @@
 #' @export
 #'
 scale_npcx_continuous <- function(...) {
-  ggplot2::continuous_scale(aesthetics = "npcx",
-    scale_name = "position_npc",
+  ggplot2::continuous_scale(
+    aesthetics = "npcx",
     palette = identity, name = NULL, breaks = NULL,
     minor_breaks = NULL, labels = NULL, limits = c(NA_real_, NA_real_),
-    expand = c(0, 0, 0, 0), oob = scales::censor, na.value = NA_real_, trans = "identity",
+    expand = c(0, 0, 0, 0), oob = scales::censor, na.value = NA_real_, transform = "identity",
     guide = "none", position = "bottom", super = ggplot2::ScaleContinuousPosition,
     ...
   )
@@ -29,10 +29,9 @@ scale_npcx_continuous <- function(...) {
 scale_npcy_continuous <- function(...) {
   ggplot2::continuous_scale(
     aesthetics = "npcy",
-    scale_name = "position_npc",
     palette = identity, name = NULL, breaks = NULL,
     minor_breaks = NULL, labels = NULL, limits = c(NA_real_, NA_real_),
-    expand = c(0, 0, 0, 0), oob = scales::censor, na.value = NA_real_, trans = "identity",
+    expand = c(0, 0, 0, 0), oob = scales::censor, na.value = NA_real_, transform = "identity",
     guide = "none", position = "bottom", super = ggplot2::ScaleContinuousPosition,
     ...
   )
